#[non_exhaustive]pub enum PrimaryQuery {
Place(String),
AddressQuery(Box<AddressQuery>),
LocationQuery(Box<LocationQuery>),
}Expand description
Query for the primary destination. This can be either a place, a fully specified address, or a LatLng location. Some places and addresses with minimal information won’t be able to be turned into a destination.
The destinations are built around the specified primary query.
Note: only places and addresses that can have a navigational destination are supported. For example, a place that represents a house or an apartment complex can be used as the primary query, but places that represent a locality or an administrative area cannot be used as the primary query.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Place(String)
The resource name of a place, in places/{place_id} format.
AddressQuery(Box<AddressQuery>)
A street address.
LocationQuery(Box<LocationQuery>)
A precise location.