#[non_exhaustive]pub struct AddressQuery {
pub kind: Option<Kind>,
/* private fields */
}Expand description
The street address that you want to search for. Specify addresses in accordance with the format used by the national postal service of the country concerned.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.kind: Option<Kind>The address query.
Implementations
Sourceimpl AddressQuery
impl AddressQuery
Sourcepub fn address(&self) -> Option<&Box<PostalAddress>>
pub fn address(&self) -> Option<&Box<PostalAddress>>
The value of kind
if it holds a Address, None if the field is not set or
holds a different branch.
Sourcepub fn set_address<T: Into<Box<PostalAddress>>>(self, v: T) -> Self
pub fn set_address<T: Into<Box<PostalAddress>>>(self, v: T) -> Self
Sets the value of kind
to hold a Address.
Note that all the setters affecting kind are
mutually exclusive.
Example
ⓘ
use google_cloud_type::model::PostalAddress;
let x = AddressQuery::new().set_address(PostalAddress::default()/* use setters */);
assert!(x.address().is_some());
assert!(x.address_query().is_none());Sourcepub fn address_query(&self) -> Option<&String>
pub fn address_query(&self) -> Option<&String>
The value of kind
if it holds a AddressQuery, None if the field is not set or
holds a different branch.
Sourcepub fn set_address_query<T: Into<String>>(self, v: T) -> Self
pub fn set_address_query<T: Into<String>>(self, v: T) -> Self