#[non_exhaustive]pub struct Destination {
pub primary: Option<PlaceView>,
pub containing_places: Vec<PlaceView>,
pub sub_destinations: Vec<PlaceView>,
pub landmarks: Vec<Landmark>,
pub entrances: Vec<Entrance>,
pub navigation_points: Vec<NavigationPoint>,
/* private fields */
}Expand description
A destination. This includes the primary place, related places, entrances, and navigation points.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.primary: Option<PlaceView>The primary place identified by the primary_query in the request.
containing_places: Vec<PlaceView>The less precise places that the primary place is contained by. For example, the apartment complex that contains this building.
sub_destinations: Vec<PlaceView>More precise sub-destinations of the primary place. For example, units contained in a building.
Note: compared to the SubDestination returned by the Places API, this list of sub-destinations is more exhaustive, and each sub-destination contains more information.
landmarks: Vec<Landmark>Landmarks that can be used to communicate where the destination is or help with arrival.
entrances: Vec<Entrance>Entrances for this destination.
Navigation points for this destination.
Implementations
Sourceimpl Destination
impl Destination
Sourcepub fn set_primary<T>(self, v: T) -> Self
pub fn set_primary<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_primary<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_primary<T>(self, v: Option<T>) -> Self
Sourcepub fn set_containing_places<T, V>(self, v: T) -> Self
pub fn set_containing_places<T, V>(self, v: T) -> Self
Sets the value of containing_places.
Example
use google_maps_geocode_v4::model::PlaceView;
let x = Destination::new()
.set_containing_places([
PlaceView::default()/* use setters */,
PlaceView::default()/* use (different) setters */,
]);Sourcepub fn set_sub_destinations<T, V>(self, v: T) -> Self
pub fn set_sub_destinations<T, V>(self, v: T) -> Self
Sets the value of sub_destinations.
Example
use google_maps_geocode_v4::model::PlaceView;
let x = Destination::new()
.set_sub_destinations([
PlaceView::default()/* use setters */,
PlaceView::default()/* use (different) setters */,
]);Sourcepub fn set_landmarks<T, V>(self, v: T) -> Self
pub fn set_landmarks<T, V>(self, v: T) -> Self
Sourcepub fn set_entrances<T, V>(self, v: T) -> Self
pub fn set_entrances<T, V>(self, v: T) -> Self
Sets the value of navigation_points.
Example
use google_maps_geocode_v4::model::NavigationPoint;
let x = Destination::new()
.set_navigation_points([
NavigationPoint::default()/* use setters */,
NavigationPoint::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for Destination
impl Clone for Destination
Sourcefn clone(&self) -> Destination
fn clone(&self) -> Destination
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more