NavigationPoint

Struct NavigationPoint 

#[non_exhaustive]
pub struct NavigationPoint { pub navigation_point_token: String, pub display_name: Option<LocalizedText>, pub location: Option<LatLng>, pub travel_modes: Vec<TravelMode>, pub usages: Vec<Usage>, /* private fields */ }
A navigation point is a location next to a road where navigation can end.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
navigation_point_token: String

Output only. A token that can be used to identify this navigation point.

display_name: Option<LocalizedText>

The display name of this navigation point. For example, “5th Ave” or “Gate B”.

location: Option<LatLng>

A point next to the road segment where navigation should end. The point is intentionally slightly offset from the road’s centerline to clearly mark the side of the road where the place is located.

travel_modes: Vec<TravelMode>

Travel modes that are appropriate for this navigation point.

usages: Vec<Usage>

Lists usages supported by this navigation point. If empty, it does not necessarily mean its usage is restricted in any way. All navigation points can be used for general navigation.

Implementations

Source

impl NavigationPoint

pub fn new() -> Self

Creates a new default instance.

pub fn set_navigation_point_token<T: Into<String>>(self, v: T) -> Self

Sets the value of navigation_point_token.

Example
let x = NavigationPoint::new().set_navigation_point_token("example");
pub fn set_display_name<T>(self, v: T) -> Self
where T: Into<LocalizedText>,

Sets the value of display_name.

Example
use google_cloud_type::model::LocalizedText;
let x = NavigationPoint::new().set_display_name(LocalizedText::default()/* use setters */);
pub fn set_or_clear_display_name<T>(self, v: Option<T>) -> Self
where T: Into<LocalizedText>,

Sets or clears the value of display_name.

Example
use google_cloud_type::model::LocalizedText;
let x = NavigationPoint::new().set_or_clear_display_name(Some(LocalizedText::default()/* use setters */));
let x = NavigationPoint::new().set_or_clear_display_name(None::<LocalizedText>);
pub fn set_location<T>(self, v: T) -> Self
where T: Into<LatLng>,

Sets the value of location.

Example
use google_cloud_type::model::LatLng;
let x = NavigationPoint::new().set_location(LatLng::default()/* use setters */);
pub fn set_or_clear_location<T>(self, v: Option<T>) -> Self
where T: Into<LatLng>,

Sets or clears the value of location.

Example
use google_cloud_type::model::LatLng;
let x = NavigationPoint::new().set_or_clear_location(Some(LatLng::default()/* use setters */));
let x = NavigationPoint::new().set_or_clear_location(None::<LatLng>);
pub fn set_travel_modes<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<TravelMode>,

Sets the value of travel_modes.

Example
use google_maps_geocode_v4::model::navigation_point::TravelMode;
let x = NavigationPoint::new().set_travel_modes([
    TravelMode::Drive,
    TravelMode::Walk,
]);
pub fn set_usages<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Usage>,

Sets the value of usages.

Example
use google_maps_geocode_v4::model::navigation_point::Usage;
let x = NavigationPoint::new().set_usages([
    Usage::Unknown,
    Usage::Dropoff,
    Usage::Pickup,
]);