#[non_exhaustive]pub struct SearchDestinationsResponse {
pub destinations: Vec<Destination>,
/* private fields */
}Expand description
Response message for DestinationService.SearchDestinations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.destinations: Vec<Destination>A list of destinations.
The service returns one result if a primary destination can be unambiguously identified from the primary query. Otherwise, the service might return multiple results for disambiguation or zero results.
Implementations
Sourceimpl SearchDestinationsResponse
impl SearchDestinationsResponse
Sourcepub fn set_destinations<T, V>(self, v: T) -> Self
pub fn set_destinations<T, V>(self, v: T) -> Self
Sets the value of destinations.
Example
ⓘ
use google_maps_geocode_v4::model::Destination;
let x = SearchDestinationsResponse::new()
.set_destinations([
Destination::default()/* use setters */,
Destination::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for SearchDestinationsResponse
impl Clone for SearchDestinationsResponse
Sourcefn clone(&self) -> SearchDestinationsResponse
fn clone(&self) -> SearchDestinationsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SearchDestinationsResponse
impl Debug for SearchDestinationsResponse
Sourceimpl Default for SearchDestinationsResponse
impl Default for SearchDestinationsResponse
Sourcefn default() -> SearchDestinationsResponse
fn default() -> SearchDestinationsResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for SearchDestinationsResponse
impl Message for SearchDestinationsResponse
impl StructuralPartialEq for SearchDestinationsResponse