DestinationService

Trait DestinationService 

pub trait DestinationService:
    Debug
    + Send
    + Sync {
    // Provided method
    fn search_destinations(
        &self,
        _req: SearchDestinationsRequest,
        _options: RequestOptions,
    ) -> impl Future<Output = Result<Response<SearchDestinationsResponse>>> + Send { ... }
}
Defines the trait used to implement super::client::DestinationService.

Application developers may need to implement this trait to mock client::DestinationService. In other use-cases, application developers only use client::DestinationService and need not be concerned with this trait or its implementations.

Services gain new RPCs routinely. Consequently, this trait gains new methods too. To avoid breaking applications the trait provides a default implementation of each method. Most of these implementations just return an error.

Provided Methods

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors