#[non_exhaustive]pub struct NavigationPoint {
pub navigation_point_token: String,
pub display_name: Option<LocalizedText>,
pub location: Option<LatLng>,
pub travel_modes: Vec<TravelMode>,
pub usages: Vec<Usage>,
/* private fields */
}Expand description
A navigation point is a location next to a road where navigation can end.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.Output only. A token that can be used to identify this navigation point.
display_name: Option<LocalizedText>The display name of this navigation point. For example, “5th Ave” or “Gate B”.
location: Option<LatLng>A point next to the road segment where navigation should end. The point is intentionally slightly offset from the road’s centerline to clearly mark the side of the road where the place is located.
travel_modes: Vec<TravelMode>Travel modes that are appropriate for this navigation point.
usages: Vec<Usage>Lists usages supported by this navigation point. If empty, it does not
necessarily mean its usage is restricted in any way. All navigation
points can be used for general navigation.
Implementations
Sets the value of navigation_point_token.
Example
let x = NavigationPoint::new().set_navigation_point_token("example");Sourcepub fn set_display_name<T>(self, v: T) -> Selfwhere
T: Into<LocalizedText>,
pub fn set_display_name<T>(self, v: T) -> Selfwhere
T: Into<LocalizedText>,
Sets the value of display_name.
Example
use google_cloud_type::model::LocalizedText;
let x = NavigationPoint::new().set_display_name(LocalizedText::default()/* use setters */);Sourcepub fn set_or_clear_display_name<T>(self, v: Option<T>) -> Selfwhere
T: Into<LocalizedText>,
pub fn set_or_clear_display_name<T>(self, v: Option<T>) -> Selfwhere
T: Into<LocalizedText>,
Sets or clears the value of display_name.
Example
use google_cloud_type::model::LocalizedText;
let x = NavigationPoint::new().set_or_clear_display_name(Some(LocalizedText::default()/* use setters */));
let x = NavigationPoint::new().set_or_clear_display_name(None::<LocalizedText>);Sourcepub fn set_location<T>(self, v: T) -> Self
pub fn set_location<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_location<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_location<T>(self, v: Option<T>) -> Self
Sourcepub fn set_travel_modes<T, V>(self, v: T) -> Self
pub fn set_travel_modes<T, V>(self, v: T) -> Self
Sets the value of travel_modes.
Example
use google_maps_geocode_v4::model::navigation_point::TravelMode;
let x = NavigationPoint::new().set_travel_modes([
TravelMode::Drive,
TravelMode::Walk,
]);Sourcepub fn set_usages<T, V>(self, v: T) -> Self
pub fn set_usages<T, V>(self, v: T) -> Self